@@ -11,7 +11,7 @@ morphoMockup = .morphodataFromDataFrame(morphoDataFrame)
 # locally suppress warnings
 data(centaurea)
 centaurea = suppressWarnings(naMeanSubst(centaurea))
-centaurea = deletePopulation(centaurea, populationName = c("LIP", "PREL"))
+centaurea = removePopulation(centaurea, populationName = c("LIP", "PREL"))
 
 
 test_that("ploting with error parameters",  {
